@@ -37,7 +37,7 @@ struct _GnmStyle {
 	GnmBorder	*borders[MSTYLE_BORDER_DIAGONAL - MSTYLE_BORDER_TOP + 1];
 	guint32          pattern;
 
-#warning TODO use GOFont
+	/* FIXME: TODO use GOFont */
 	struct _GnmStyleFontDetails {
 		GOString	*name;
 		gboolean	bold;
@@ -64,6 +64,8 @@ struct _GnmStyle {
 	GnmInputMsg		*input_msg;
 	GnmStyleConditions	*conditions;
 	GPtrArray		*cond_styles;
+
+	GSList *deps;
 };
 
 #define elem_changed(style, elem) do { (style)->changed |= (1u << (elem)); } while(0)
