@@ -113,7 +113,7 @@ struct _Sheet {
 	GnmSheetSize size;
 
 	/* tile related data */
-	int tile_top_level, max_width, max_height;
+	int tile_top_level;
 };
 
 #define GNM_SHEET_TYPE	(gnm_sheet_get_type ())
@@ -157,11 +157,11 @@ struct _GnmCellIter {
 	GnmParsePos  pp;
 	ColRowInfo  *ci, *ri;
 };
-GnmValue *sheet_foreach_cell_in_range	(Sheet *sheet, CellIterFlags flags,
-				  int start_col, int start_row,
-				  int end_col, int end_row,
-				  CellIterFunc callback,
-				  gpointer     closure);
+GnmValue *sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
+				       int start_col, int start_row,
+				       int end_col, int end_row,
+				       CellIterFunc callback,
+				       gpointer     closure);
 void	    sheet_cell_foreach	 (Sheet const *sheet,
 				  GHFunc callback, gpointer data);
 unsigned    sheet_cells_count	 (Sheet const *sheet);
@@ -310,7 +310,8 @@ void	 sheet_scrollbar_config		(Sheet const *sheet);
 
 void     sheet_mark_dirty	(Sheet *sheet);
 GnmRange    sheet_get_extent	(Sheet const *sheet,
-				 gboolean spans_and_merges_extend);
+				 gboolean spans_and_merges_extend,
+				 gboolean include_hidden);
 GnmRange    sheet_get_cells_extent (Sheet const *sheet);
 GnmRange    sheet_get_printarea	(Sheet const *sheet,
 				 gboolean include_styles,
